@@ -1,6 +1,7 @@
-import tqdm
-from multiprocessing import Pool, cpu_count, RLock
 from functools import partial, reduce
+from multiprocessing import Pool, RLock, cpu_count
+
+import tqdm
 
 MULTI_WORKERS_NUM = cpu_count() - 1
 
